==> dde-session-shell_5.4.13.orig.tar.xz: dde-session-shell-5.4.13/translations/dde-session-shell_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_HK" version="2.1">
<context>
    <name>ContentWidget</name>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="357"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>以上程序阻止關機，強制關機可能會導致其數據丟失。</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="358"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="363"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="367"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="371"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="375"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>您可以點擊“取消”然後關閉這些程序。</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="362"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>以上程序阻止重啟，強制重啟可能會導致其數據丟失。</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="366"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>以上程序阻止待機，強制待機可能會導致其數據丟失。</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="370"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>以上程序阻止休眠，強制休眠可能會導致其數據丟失。</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="374"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>以上程序阻止註銷，強制註銷可能會導致其數據丟失。</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="391"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="435"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="460"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="614"/>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="394"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="437"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="463"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="617"/>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="397"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="620"/>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="399"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="623"/>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="401"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="466"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="629"/>
        <source>Log out</source>
        <translation>註銷</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="461"/>
        <source>Are you sure you want to shut down?</source>
        <translation>您確定要關機嗎？</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="464"/>
        <source>Are you sure you want to reboot?</source>
        <translation>您確定要重啟嗎？</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="467"/>
        <source>Are you sure you want to log out?</source>
        <translation>您確定要註銷嗎？</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="626"/>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="632"/>
        <source>Switch user</source>
        <translation>切換使用者</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="637"/>
        <source>Switch system</source>
        <translation>切換系統</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="329"/>
        <source>Wrong Password</source>
        <translation>密碼錯誤</translation>
    </message>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="333"/>
        <source>The account or password is not correct. Please enter again.</source>
        <translation>帳戶或密碼不正確，請重新輸入。</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="90"/>
        <location filename="../src/widgets/inhibitwarnview.cpp" line="90"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="405"/>
        <source>Lock Screen</source>
        <translation>鎖屏</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="409"/>
        <source>Failed to lock screen</source>
        <translation>鎖屏失敗</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="291"/>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>指紋密碼驗證超時，請手動輸入密碼</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="309"/>
        <source>Failed to match fingerprint</source>
        <translation>指紋解鎖失敗</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="339"/>
        <source>Wrong Password</source>
        <translation>密碼錯誤</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="45"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="130"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="133"/>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>此電腦還有以上帳戶在登錄，關閉電腦會導致其數據丟失，是否要關閉此電腦？</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="134"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="137"/>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>此電腦還有以上帳戶在登錄，重啟電腦會導致其數據丟失，是否要重啟此電腦？</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="172"/>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="178"/>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="33"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="184"/>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="190"/>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="196"/>
        <source>Log out</source>
        <translation>註銷</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="202"/>
        <source>Switch user</source>
        <translation>切換使用者</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="210"/>
        <source>Switch system</source>
        <translation>切換系統</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
        <location filename="../src/widgets/systemmonitor.cpp" line="45"/>
        <source>Start system monitor</source>
        <translation>啟動系統監視器</translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="193"/>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="197"/>
        <source>Account</source>
        <translation>帳戶</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="239"/>
        <source>Please enter the account</source>
        <translation>請輸入帳號</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="246"/>
        <source>Please enter the password</source>
        <translation>請輸入密碼</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/session-widgets/userloginwidget.cpp" line="338"/>
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="149"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>以上程序阻止關機，強制關機可能會導致其數據丟失。</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="150"/>
        <location filename="../src/widgets/warningcontent.cpp" line="155"/>
        <location filename="../src/widgets/warningcontent.cpp" line="159"/>
        <location filename="../src/widgets/warningcontent.cpp" line="163"/>
        <location filename="../src/widgets/warningcontent.cpp" line="167"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>您可以點擊“取消”然後關閉這些程序。</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="154"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>以上程序阻止重啟，強制重啟可能會導致其數據丟失。</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="158"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>以上程序阻止待機，強制待機可能會導致其數據丟失。</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="162"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>以上程序阻止休眠，強制休眠可能會導致其數據丟失。</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="166"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>以上程序阻止註銷，強制註銷可能會導致其數據丟失。</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="182"/>
        <location filename="../src/widgets/warningcontent.cpp" line="235"/>
        <location filename="../src/widgets/warningcontent.cpp" line="267"/>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="185"/>
        <location filename="../src/widgets/warningcontent.cpp" line="237"/>
        <location filename="../src/widgets/warningcontent.cpp" line="270"/>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="188"/>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="190"/>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="192"/>
        <location filename="../src/widgets/warningcontent.cpp" line="273"/>
        <source>Log out</source>
        <translation>註銷</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="268"/>
        <source>Are you sure you want to shut down?</source>
        <translation>您確定要關機嗎？</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="271"/>
        <source>Are you sure you want to reboot?</source>
        <translation>您確定要重啟嗎？</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="274"/>
        <source>Are you sure you want to log out?</source>
        <translation>您確定要註銷嗎？</translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.14.orig.tar.xz: dde-session-shell-5.5.14/translations/dde-session-shell_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>面容</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>請驗證人臉ID</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>人臉ID已鎖定，請輸入密碼</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>請驗證指紋</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>指紋已鎖定，請輸入密碼</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>虹膜</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>請驗證虹膜ID</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>虹膜ID已鎖定，請輸入密碼</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>密碼錯誤</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>請輸入密碼</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>重置密碼</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘記密碼？</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>重置密碼</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘記密碼？</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN錯誤</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>需要使用UKEY認證</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>識別到UKEY，需要輸入PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>帳戶</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>密碼將於%n天後過期，請及時修改密碼</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>密碼已過期，請修改</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>帳戶錯誤</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>密碼錯誤</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>鎖屏</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>鎖屏失敗</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>指紋密碼驗證超時，請手動輸入密碼</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>指紋解鎖失敗</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>此電腦還有以上帳戶在登錄，關閉電腦會導致其數據丟失，是否要關閉此電腦？</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>此電腦還有以上帳戶在登錄，重啟電腦會導致其數據丟失，是否要重啟此電腦？</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>您已開啟高級別等級保護，無法切換Wayland模式，請於“安全中心”關閉高級別等級保護後再試</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>註銷</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>切換使用者</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>切換系統</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>啟動系統監視器</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>以上程序阻止關機，強制關機可能會導致其數據丟失。</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>您可以點擊“取消”然後關閉這些程序。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>以上程序阻止重啟，強制重啟可能會導致其數據丟失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>以上程序阻止待機，強制待機可能會導致其數據丟失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>以上程序阻止休眠，強制休眠可能會導致其數據丟失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>以上程序阻止註銷，強制註銷可能會導致其數據丟失。</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>註銷</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>您確定要關機嗎？</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>您確定要重啟嗎？</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>您確定要註銷嗎？</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>關閉</translation>
    </message>
</context>
</TS>
